@@ -33,8 +33,6 @@
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
-#elif defined(_MSC_VER)
-#include "config-msvc.h"
 #endif
 
 #include "syshead.h"
@@ -69,7 +67,8 @@ openvpn_base64_encode(const void *data, int size, char **str)
     }
     q = (const unsigned char *) data;
     i = 0;
-    for (i = 0; i < size; ) {
+    for (i = 0; i < size; )
+    {
         c = q[i++];
         c *= 256;
         if (i < size)
@@ -107,10 +106,12 @@ pos(char c)
 {
     char *p;
     for (p = base64_chars; *p; p++)
+    {
         if (*p == c)
         {
             return p - base64_chars;
         }
+    }
     return -1;
 }
 
@@ -126,7 +127,8 @@ token_decode(const char *token)
     {
         return DECODE_ERROR;
     }
-    for (i = 0; i < 4; i++) {
+    for (i = 0; i < 4; i++)
+    {
         val *= 64;
         if (token[i] == '=')
         {
@@ -164,7 +166,8 @@ openvpn_base64_decode(const char *str, void *data, int size)
     {
         e = q + size;
     }
-    for (p = str; *p && (*p == '=' || strchr(base64_chars, *p)); p += 4) {
+    for (p = str; *p && (*p == '=' || strchr(base64_chars, *p)); p += 4)
+    {
         unsigned int val = token_decode(p);
         unsigned int marker = (val >> 24) & 0xff;
         if (val == DECODE_ERROR)
