@@ -1036,7 +1036,7 @@ plugin_return_print(const int msglevel, const char *prefix, const struct plugin_
         msg(msglevel, "PLUGIN #%d (%s)", i, prefix);
         while (l)
         {
-            msg(msglevel, "[%d] '%s' -> '%s'\n",
+            msg(msglevel, "[%d] '%s' -> '%s'",
                 ++count,
                 l->name,
                 l->value);
